| Title: | Locating Distributional Changes in Highly Dependent Time Series |
|---|---|
| Description: | Provides algorithms to locate multiple distributional change-points in piecewise stationary time series. The algorithms are provably consistent, even in the presence of long-range dependencies. Knowledge of the number of change-points is not required. The code is written in Go and interfaced with R. |
| Authors: | Lukas Zierahn [cre, aut], Azadeh Khaleghi [aut] |
| Maintainer: | Lukas Zierahn <[email protected]> |
| License: | GPL |
| Version: | 1.0.3 |
| Built: | 2026-05-18 06:44:56 UTC |
| Source: | https://github.com/azalk/gochest |
Returns the position of changepoints in the sequence. NOTE: PyChest needs to be installed first by calling ‘install_PyChest’.
find_changepoints(sample, minimum_distance, process_count)find_changepoints(sample, minimum_distance, process_count)
sample |
A vector of floats corresponding to the piecewise stationary sample where the retrospective changes are to be sought |
minimum_distance |
A real number between 0 and 1 corresponding to a lower-bound on the minimum normalized length of the stationary segments (as percentage of total sample length) |
process_count |
The different number of distinct stationary processes present. |
The list of changepoints in increasing size
Khaleghi A, Ryabko D (2014). “Asymptotically consistent estimation of the number of change points in highly dependent time series.” In International Conference on Machine Learning, 539–547.
Khaleghi A, Ryabko D (2012). “Locating changes in highly dependent data with unknown number of change points.” In Advances in Neural Information Processing Systems, 3086–3094.
Initializes the package and installs/updates PyChest into the local reticulate-Python environment
install_PyChest()install_PyChest()
No return value, called to install the PyChest Package
Returns the position of changepoints in the sequence. NOTE: PyChest needs to be installed first by calling ‘install_PyChest’.
list_estimator(sample, minimum_distance)list_estimator(sample, minimum_distance)
sample |
A vector of floats corresponding to the piecewise stationary sample where the retrospective changes are to be sought |
minimum_distance |
A real number between 0 and 1 corresponding to a lower-bound on the minimum normalized length of the stationary segments (as percentage of total sample length) |
The list of changepoints in order of score
Khaleghi A, Ryabko D (2012). “Locating changes in highly dependent data with unknown number of change points.” In Advances in Neural Information Processing Systems, 3086–3094.